import click
from hello_world import greet_user

@click.command()
@click.argument('user_input', nargs=-1, type=str)
def greet(user_input):
    # Join all arguments into a single string
    input_str = ' '.join(user_input)
    response = greet_user(input_str)
    click.echo(response)

if __name__ == '__main__':
    greet()



def hello():
    return "Hello, World!"

def greet_user(user_input):
    if user_input.lower() == "hi":
        return hello()
    if user_input.lower() == "how are you?":
        return "i am fine. how about you?"
    return "Goodbye"




import unittest
from hello_world import greet_user

class TestHelloWorld(unittest.TestCase):

    def test_greet_user(self):
        self.assertEqual(greet_user("hi"), "Hello, World!")
        self.assertEqual(greet_user("HI"), "Hello, World!")
        self.assertEqual(greet_user("hello"), "Goodbye")
        self.assertEqual(greet_user("bye"), "Goodbye")

if __name__ == '__main__':
    unittest.main()

